## 1.37.0.0 (2023-08-16)

Bump influxdb-client to 1.37.* (#10585)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 1.36.0.9 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 1.36.0.8 (2023-04-27)

influxdb-client: fix stubtest (#10090)

## 1.36.0.7 (2023-03-27)

Add defaults for third-party stubs I-L (#9955)

## 1.36.0.6 (2023-02-26)

Improve many `__(a)exit__` annotations (#9696)

## 1.36.0.5 (2023-02-24)

Fix stubtest for `influxdb-client` (#9808)

Fixes #9805

## 1.36.0.4 (2023-02-21)

Integrate requirements-stubtest.txt into METADATA.toml (#9778)

## 1.36.0.3 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 1.36.0.2 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 1.36.0.1 (2023-02-07)

Bump mypy to 1.0 (#9684)

## 1.36.0.0 (2023-01-27)

[stubsabot] Bump influxdb-client to 1.36.* (#9594)

Release: https://pypi.org/pypi/influxdb-client/1.36.0
Homepage: https://github.com/influxdata/influxdb-client-python
Diff: https://github.com/influxdata/influxdb-client-python/compare/v1.35.0...v1.36.0

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 4 files included in typeshed's stubs have been modified or renamed: `influxdb_client/client/flux_table.py`, `influxdb_client/client/write/point.py`, `influxdb_client/client/write_api.py`, `influxdb_client/version.py`.
 - Total lines of Python code added: 151.
 - Total lines of Python code deleted: 16.

## 1.35.0.2 (2023-01-14)

Allow influxdb-client to be completely tested by stubtest (#9529)

## 1.35.0.1 (2023-01-02)

[influxdb-client] Annotate Point and partially client classes (#9442)

## 1.35.0.0 (2022-12-31)

Add stubs for influxdb-client (#9429)

